translate.convert.dtd2po

Package translate :: Package convert :: Module dtd2po |
[hide private]
[frames] | no frames]

# Module dtd2po

source code

script to convert a mozilla .dtd UTF-8 localization format to a gettext .po localization file using the po and dtd modules, and the dtd2po convertor class which is in this module You can convert back to .dtd using po2dtd.py

Classes | [hide private]
| dtd2po

Functions | [hide private]
is_css_entity(entity) Says if the given entity is likely to contain CSS that should not be translated. | source code
convertdtd(inputfile, outputfile, templatefile, pot=False, duplicatestyle="msgctxt") reads in inputfile and templatefile using dtd, converts using dtd2po, writes to outputfile | source code
main(argv=None) | source code

Imports: po, dtd, quote, accesskeyfn